#[derive(Position)]Expand description
Automatically implement the hoomd_microstate::property::Position trait.
The derived implementation returns a reference to the structure’s position
field.
Valid on structs with named fields.
#[derive(Position)]Automatically implement the hoomd_microstate::property::Position trait.
The derived implementation returns a reference to the structure’s position
field.
Valid on structs with named fields.